//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'('",
	"')'",
	"';'",
	"'{'",
	"'}'",
	"']'",
	"'\"'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:1067
const src = `<?php
trait foo
{
    private static function bas($a = null)
    {
        echo $a;
    }
}
`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 40,
	133, 395,
	153, 395,
	-2, 401,
	-1, 78,
	133, 397,
	153, 397,
	-2, 372,
	-1, 94,
	153, 393,
	-2, 389,
	-1, 199,
	133, 395,
	153, 395,
	-2, 301,
	-1, 205,
	133, 395,
	153, 395,
	-2, 303,
	-1, 305,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 325,
	-1, 306,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 326,
	-1, 307,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 327,
	-1, 308,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 328,
	-1, 309,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 329,
	-1, 310,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 330,
	-1, 311,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 331,
	-1, 312,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 332,
	-1, 313,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 333,
	-1, 319,
	133, 395,
	153, 395,
	-2, 209,
	-1, 358,
	133, 396,
	153, 396,
	-2, 334,
	-1, 458,
	133, 395,
	153, 395,
	-2, 192,
	-1, 492,
	160, 265,
	-2, 270,
	-1, 544,
	133, 395,
	153, 395,
	-2, 180,
	-1, 570,
	88, 244,
	-2, 250,
	-1, 589,
	133, 395,
	153, 395,
	-2, 191,
	-1, 609,
	133, 395,
	153, 395,
	-2, 181,
	-1, 656,
	133, 399,
	153, 399,
	-2, 183,
	-1, 719,
	105, 76,
	-2, 78,
	-1, 736,
	160, 265,
	-2, 270,
}

const yyPrivate = 57344

const yyLast = 6281

var yyAct = [...]int{

	25, 114, 670, 660, 572, 366, 554, 627, 711, 669,
	651, 686, 623, 558, 170, 98, 556, 559, 543, 121,
	121, 121, 592, 485, 133, 102, 108, 269, 274, 526,
	4, 527, 167, 242, 94, 322, 78, 494, 270, 318,
	244, 5, 77, 116, 602, 132, 271, 126, 198, 6,
	76, 206, 207, 208, 209, 210, 129, 212, 213, 112,
	215, 216, 217, 218, 219, 220, 221, 222, 223, 224,
	2, 225, 226, 227, 673, 656, 75, 646, 647, 586,
	40, 233, 455, 204, 204, 203, 203, 514, 720, 113,
	682, 201, 201, 352, 92, 92, 679, 246, 127, 200,
	200, 92, 249, 234, 766, 767, 253, 254, 446, 646,
	647, 677, 639, 515, 758, 250, 272, 252, 705, 276,
	277, 699, 259, 659, 493, 265, 330, 329, 460, 199,
	205, 104, 689, 460, 460, 460, 288, 289, 290, 291,
	292, 293, 294, 295, 296, 297, 298, 299, 300, 301,
	302, 303, 304, 305, 306, 307, 308, 309, 310, 311,
	312, 313, 314, 316, 645, 320, 235, 236, 324, 353,
	240, 687, 93, 93, 255, 239, 539, 666, 166, 93,
	452, 513, 336, 338, 339, 340, 341, 342, 343, 344,
	345, 346, 347, 348, 349, 262, 761, 350, 204, 266,
	203, 746, 101, 357, 594, 332, 201, 103, 664, 530,
	524, 471, 359, 740, 200, 360, 739, 287, 726, 284,
	695, 560, 690, 137, 139, 138, 674, 675, 282, 262,
	683, 362, 440, 643, 632, 606, 449, 605, 608, 603,
	453, 601, 246, 161, 319, 162, 135, 136, 140, 142,
	141, 154, 155, 152, 153, 156, 157, 158, 159, 160,
	150, 151, 144, 145, 143, 146, 148, 149, 476, 489,
	704, 204, 464, 203, 354, 454, 467, 104, 470, 201,
	461, 147, 204, 4, 203, 334, 481, 200, 133, 326,
	201, 280, 279, 278, 5, 256, 759, 747, 200, 694,
	736, 688, 6, 693, 684, 363, 441, 538, 104, 678,
	616, 591, 443, 541, 445, 517, 484, 451, 251, 445,
	443, 545, 468, 658, 610, 462, 562, 563, 458, 665,
	479, 590, 496, 482, 497, 492, 475, 498, 499, 459,
	333, 480, 331, 241, 214, 117, 211, 465, 99, 196,
	266, 165, 164, 547, 501, 163, 119, 562, 563, 127,
	122, 118, 505, 104, 137, 139, 138, 197, 495, 286,
	104, 283, 92, 115, 100, 104, 117, 634, 97, 99,
	281, 261, 101, 607, 161, 264, 162, 135, 136, 140,
	142, 141, 154, 155, 152, 153, 156, 157, 158, 159,
	160, 150, 151, 144, 145, 143, 146, 148, 149, 576,
	577, 578, 575, 574, 573, 104, 264, 104, 546, 95,
	488, 249, 147, 576, 577, 578, 575, 574, 573, 264,
	264, 117, 363, 441, 99, 743, 234, 249, 117, 356,
	264, 99, 447, 202, 110, 111, 469, 355, 234, 229,
	93, 228, 273, 569, 96, 741, 571, 246, 519, 587,
	246, 122, 107, 73, 74, 626, 625, 569, 525, 234,
	571, 104, 742, 92, 238, 624, 534, 276, 536, 97,
	104, 473, 466, 701, 540, 470, 260, 470, 109, 130,
	4, 552, 263, 522, 614, 615, 621, 518, 442, 235,
	236, 5, 532, 730, 104, 535, 448, 110, 111, 6,
	579, 235, 236, 323, 172, 588, 549, 585, 232, 511,
	95, 204, 204, 203, 203, 551, 542, 561, 583, 201,
	201, 564, 235, 236, 509, 599, 234, 200, 200, 117,
	470, 446, 99, 147, 202, 470, 470, 472, 246, 460,
	595, 93, 612, 328, 171, 204, 729, 203, 327, 266,
	598, 528, 175, 201, 691, 646, 647, 319, 544, 258,
	507, 200, 510, 508, 234, 629, 174, 168, 620, 230,
	204, 611, 203, 619, 604, 42, 633, 661, 201, 176,
	177, 246, 649, 646, 647, 561, 200, 631, 444, 235,
	236, 589, 276, 335, 628, 178, 180, 179, 630, 237,
	470, 246, 470, 169, 593, 733, 636, 638, 706, 597,
	528, 173, 641, 667, 635, 490, 609, 654, 640, 285,
	644, 529, 673, 676, 662, 652, 231, 235, 236, 637,
	596, 671, 106, 204, 655, 203, 120, 685, 648, 617,
	650, 201, 561, 470, 486, 692, 146, 148, 149, 200,
	477, 698, 681, 456, 1, 7, 123, 124, 703, 105,
	257, 351, 147, 45, 707, 700, 46, 91, 717, 702,
	506, 69, 765, 714, 593, 715, 528, 713, 725, 544,
	712, 710, 672, 697, 568, 668, 561, 724, 622, 570,
	567, 732, 566, 613, 728, 696, 553, 735, 708, 548,
	716, 321, 722, 717, 245, 734, 243, 317, 131, 738,
	128, 652, 125, 537, 721, 744, 745, 680, 275, 373,
	374, 375, 376, 377, 750, 378, 379, 380, 416, 417,
	531, 13, 39, 751, 12, 716, 756, 755, 754, 752,
	576, 577, 578, 575, 574, 573, 38, 44, 760, 41,
	762, 555, 557, 763, 35, 748, 267, 3, 365, 768,
	663, 561, 618, 0, 0, 0, 628, 0, 0, 0,
	0, 381, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 382, 383, 0, 386, 387,
	388, 367, 368, 369, 370, 371, 372, 384, 385, 0,
	0, 364, 0, 92, 0, 0, 0, 0, 0, 0,
	389, 390, 391, 392, 393, 394, 395, 396, 397, 398,
	399, 419, 420, 421, 422, 423, 411, 412, 413, 414,
	415, 400, 401, 402, 403, 404, 405, 406, 407, 408,
	409, 410, 0, 431, 429, 430, 426, 427, 0, 418,
	424, 425, 432, 433, 435, 434, 436, 437, 373, 374,
	375, 376, 377, 0, 378, 379, 380, 416, 417, 428,
	439, 438, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 93, 157, 158, 159, 160, 150, 151, 144, 145,
	143, 146, 148, 149, 576, 577, 578, 575, 574, 573,
	144, 145, 143, 146, 148, 149, 0, 147, 0, 0,
	381, 0, 0, 0, 0, 0, 0, 0, 0, 147,
	0, 0, 0, 0, 382, 383, 0, 386, 387, 388,
	367, 368, 369, 370, 371, 372, 384, 385, 569, 0,
	719, 571, 0, 0, 0, 0, 0, 0, 0, 389,
	390, 391, 392, 393, 394, 395, 396, 397, 398, 399,
	419, 420, 421, 422, 423, 411, 412, 413, 414, 415,
	400, 401, 402, 403, 404, 405, 406, 407, 408, 409,
	410, 565, 431, 429, 430, 426, 427, 0, 418, 424,
	425, 432, 433, 435, 434, 436, 437, 373, 374, 375,
	376, 377, 138, 378, 379, 380, 416, 417, 718, 439,
	438, 99, 0, 0, 0, 0, 0, 737, 0, 0,
	161, 0, 162, 135, 136, 140, 142, 141, 154, 155,
	152, 153, 156, 157, 158, 159, 160, 150, 151, 144,
	145, 143, 146, 148, 149, 0, 0, 0, 0, 381,
	0, 0, 0, 0, 0, 0, 0, 0, 147, 0,
	0, 0, 0, 382, 383, 0, 386, 387, 388, 367,
	368, 369, 370, 371, 372, 384, 385, 0, 0, 719,
	0, 0, 0, 0, 0, 0, 0, 0, 389, 390,
	391, 392, 393, 394, 395, 396, 397, 398, 399, 419,
	420, 421, 422, 423, 411, 412, 413, 414, 415, 400,
	401, 402, 403, 404, 405, 406, 407, 408, 409, 410,
	0, 431, 429, 430, 426, 427, 0, 418, 424, 425,
	432, 433, 435, 434, 436, 437, 0, 0, 0, 0,
	0, 0, 56, 57, 58, 59, 60, 718, 439, 438,
	99, 70, 71, 0, 72, 0, 709, 0, 162, 135,
	136, 140, 142, 141, 154, 155, 152, 153, 156, 157,
	158, 159, 160, 150, 151, 144, 145, 143, 146, 148,
	149, 0, 0, 0, 0, 0, 0, 50, 51, 0,
	0, 0, 0, 52, 147, 53, 48, 49, 61, 62,
	63, 64, 65, 66, 67, 68, 0, 96, 0, 47,
	0, 0, 0, 0, 22, 73, 74, 0, 0, 0,
	0, 43, 79, 80, 33, 0, 92, 0, 24, 0,
	0, 0, 97, 23, 15, 14, 0, 16, 0, 27,
	0, 28, 0, 0, 17, 0, 0, 0, 18, 19,
	32, 34, 0, 20, 30, 0, 0, 31, 10, 0,
	21, 0, 26, 0, 55, 8, 36, 37, 0, 0,
	0, 0, 0, 95, 0, 88, 84, 85, 86, 81,
	82, 0, 0, 0, 0, 0, 0, 89, 0, 0,
	0, 0, 9, 87, 83, 99, 0, 54, 0, 29,
	11, 523, 0, 90, 93, 56, 57, 58, 59, 60,
	0, 0, 0, 0, 70, 71, 161, 72, 162, 135,
	136, 140, 142, 141, 154, 155, 152, 153, 156, 157,
	158, 159, 160, 150, 151, 144, 145, 143, 146, 148,
	149, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	50, 51, 0, 0, 147, 0, 52, 0, 53, 48,
	49, 61, 62, 63, 64, 65, 66, 67, 68, 0,
	96, 0, 47, 0, 0, 0, 0, 22, 73, 74,
	0, 0, 0, 0, 43, 79, 80, 33, 0, 92,
	0, 24, 0, 0, 0, 97, 23, 15, 14, 0,
	16, 0, 27, 0, 28, 0, 0, 17, 0, 0,
	0, 18, 19, 32, 34, 0, 20, 30, 0, 0,
	31, 10, 0, 21, 0, 26, 0, 55, 8, 36,
	37, 0, 0, 0, 0, 0, 95, 0, 88, 84,
	85, 86, 81, 82, 0, 0, 0, 0, 0, 0,
	89, 0, 0, 0, 0, 9, 87, 83, 99, 0,
	54, 0, 29, 11, 463, 0, 90, 93, 56, 57,
	58, 59, 60, 0, 0, 0, 0, 70, 71, 0,
	72, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 50, 51, 147, 0, 0, 0, 52,
	0, 53, 48, 49, 61, 62, 63, 64, 65, 66,
	67, 68, 0, 96, 0, 47, 0, 0, 0, 0,
	22, 73, 74, 0, 0, 0, 0, 43, 79, 80,
	33, 0, 92, 0, 24, 0, 0, 0, 97, 23,
	15, 14, 0, 16, 0, 27, 0, 28, 0, 0,
	17, 0, 0, 0, 18, 19, 32, 34, 0, 20,
	30, 0, 0, 31, 10, 0, 21, 0, 26, 0,
	55, 8, 36, 37, 0, 0, 0, 0, 0, 95,
	0, 88, 84, 85, 86, 81, 82, 0, 0, 0,
	0, 0, 0, 89, 0, 0, 0, 0, 9, 87,
	83, 99, 0, 54, 0, 29, 11, 361, 0, 90,
	93, 56, 57, 58, 59, 60, 0, 0, 0, 0,
	70, 71, 161, 72, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 50, 51, 0, 0,
	147, 0, 52, 0, 53, 48, 49, 61, 62, 63,
	64, 65, 66, 67, 68, 0, 96, 0, 47, 0,
	0, 0, 0, 22, 73, 74, 0, 0, 0, 0,
	43, 79, 80, 33, 0, 92, 0, 24, 0, 0,
	0, 97, 23, 15, 14, 0, 16, 0, 27, 0,
	28, 0, 0, 17, 0, 0, 0, 18, 19, 32,
	34, 0, 20, 30, 0, 0, 31, 0, 0, 21,
	0, 26, 0, 55, 0, 36, 0, 0, 0, 0,
	0, 0, 95, 0, 88, 84, 85, 86, 81, 82,
	0, 0, 0, 0, 0, 0, 89, 0, 0, 0,
	0, 117, 87, 83, 99, 0, 54, 0, 29, 11,
	769, 0, 90, 93, 56, 57, 58, 59, 60, 0,
	0, 0, 0, 70, 71, 0, 72, 0, 140, 142,
	141, 154, 155, 152, 153, 156, 157, 158, 159, 160,
	150, 151, 144, 145, 143, 146, 148, 149, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 50,
	51, 147, 0, 0, 0, 52, 0, 53, 48, 49,
	61, 62, 63, 64, 65, 66, 67, 68, 0, 96,
	0, 47, 0, 0, 0, 0, 22, 73, 74, 0,
	0, 0, 0, 43, 79, 80, 33, 0, 92, 0,
	24, 0, 0, 0, 97, 23, 15, 14, 0, 16,
	0, 27, 0, 28, 0, 0, 17, 0, 0, 0,
	18, 19, 32, 34, 0, 20, 30, 0, 0, 31,
	0, 0, 21, 0, 26, 0, 55, 0, 36, 0,
	0, 0, 0, 0, 0, 95, 0, 88, 84, 85,
	86, 81, 82, 0, 0, 0, 0, 0, 0, 89,
	0, 0, 0, 0, 117, 87, 83, 99, 0, 54,
	0, 29, 11, 764, 0, 90, 93, 56, 57, 58,
	59, 60, 0, 0, 0, 0, 70, 71, 0, 72,
	0, 0, 142, 141, 154, 155, 152, 153, 156, 157,
	158, 159, 160, 150, 151, 144, 145, 143, 146, 148,
	149, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 50, 51, 147, 0, 0, 0, 52, 0,
	53, 48, 49, 61, 62, 63, 64, 65, 66, 67,
	68, 0, 96, 0, 47, 0, 0, 0, 0, 22,
	73, 74, 0, 0, 0, 0, 43, 79, 80, 33,
	0, 92, 0, 24, 0, 0, 0, 97, 23, 15,
	14, 0, 16, 757, 27, 0, 28, 0, 0, 17,
	0, 0, 0, 18, 19, 32, 34, 0, 20, 30,
	0, 0, 31, 0, 0, 21, 0, 26, 0, 55,
	0, 36, 0, 0, 0, 0, 0, 0, 95, 0,
	88, 84, 85, 86, 81, 82, 0, 0, 0, 0,
	0, 0, 89, 0, 0, 0, 0, 117, 87, 83,
	99, 0, 54, 0, 29, 11, 0, 0, 90, 93,
	56, 57, 58, 59, 60, 0, 0, 0, 0, 70,
	71, 0, 72, 141, 154, 155, 152, 153, 156, 157,
	158, 159, 160, 150, 151, 144, 145, 143, 146, 148,
	149, 150, 151, 144, 145, 143, 146, 148, 149, 0,
	0, 0, 0, 0, 147, 50, 51, 0, 0, 0,
	0, 52, 147, 53, 48, 49, 61, 62, 63, 64,
	65, 66, 67, 68, 0, 96, 0, 47, 0, 0,
	0, 0, 22, 73, 74, 0, 0, 0, 0, 43,
	79, 80, 33, 0, 92, 0, 24, 0, 0, 0,
	97, 23, 15, 14, 0, 16, 0, 27, 0, 28,
	0, 0, 17, 0, 0, 0, 18, 19, 32, 34,
	0, 20, 30, 0, 0, 31, 0, 0, 21, 0,
	26, 0, 55, 0, 36, 0, 0, 0, 0, 0,
	0, 95, 0, 88, 84, 85, 86, 81, 82, 0,
	0, 0, 0, 0, 0, 89, 0, 0, 0, 0,
	117, 87, 83, 99, 0, 54, 0, 29, 11, 749,
	0, 90, 93, 56, 57, 58, 59, 60, 0, 0,
	0, 0, 70, 71, 0, 72, 154, 155, 152, 153,
	156, 157, 158, 159, 160, 150, 151, 144, 145, 143,
	146, 148, 149, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 147, 0, 50, 51,
	0, 0, 0, 0, 52, 0, 53, 48, 49, 61,
	62, 63, 64, 65, 66, 67, 68, 0, 96, 0,
	47, 0, 0, 0, 0, 22, 73, 74, 0, 0,
	0, 0, 43, 79, 80, 33, 0, 92, 0, 24,
	0, 0, 0, 97, 23, 15, 14, 0, 16, 0,
	27, 0, 28, 0, 0, 17, 0, 0, 0, 18,
	19, 32, 34, 0, 20, 30, 0, 0, 31, 0,
	0, 21, 0, 26, 0, 55, 0, 36, 0, 0,
	0, 0, 0, 0, 95, 0, 88, 84, 85, 86,
	81, 82, 0, 0, 0, 0, 0, 0, 89, 0,
	0, 0, 0, 117, 87, 83, 99, 0, 54, 0,
	29, 11, 731, 0, 90, 93, 56, 57, 58, 59,
	60, 0, 0, 0, 0, 70, 71, 0, 72, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 181, 182, 183, 184, 186, 187, 188,
	189, 190, 191, 192, 193, 185, 0, 0, 0, 0,
	0, 50, 51, 0, 0, 0, 0, 52, 0, 53,
	48, 49, 61, 62, 63, 64, 65, 66, 67, 68,
	0, 96, 0, 47, 194, 195, 0, 0, 22, 73,
	74, 0, 0, 0, 0, 43, 79, 80, 33, 0,
	92, 0, 24, 0, 0, 0, 97, 23, 15, 14,
	0, 16, 0, 27, 727, 28, 0, 0, 17, 0,
	0, 0, 18, 19, 32, 34, 0, 20, 30, 0,
	0, 31, 0, 0, 21, 0, 26, 0, 55, 0,
	36, 0, 0, 0, 0, 0, 0, 95, 0, 88,
	84, 85, 86, 81, 82, 0, 0, 0, 0, 0,
	0, 89, 0, 0, 0, 0, 117, 87, 83, 99,
	0, 54, 0, 29, 11, 0, 0, 90, 93, 56,
	57, 58, 59, 60, 0, 0, 0, 0, 70, 71,
	0, 72, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 50, 51, 0, 0, 0, 0,
	52, 0, 53, 48, 49, 61, 62, 63, 64, 65,
	66, 67, 68, 0, 96, 0, 47, 0, 0, 0,
	0, 22, 73, 74, 0, 0, 0, 0, 43, 79,
	80, 33, 0, 92, 0, 24, 0, 0, 0, 97,
	23, 15, 14, 0, 16, 0, 27, 0, 28, 657,
	0, 17, 0, 0, 0, 18, 19, 32, 34, 0,
	20, 30, 0, 0, 31, 0, 0, 21, 0, 26,
	0, 55, 0, 36, 0, 0, 0, 0, 0, 0,
	95, 0, 88, 84, 85, 86, 81, 82, 0, 0,
	0, 0, 0, 0, 89, 0, 0, 0, 0, 117,
	87, 83, 99, 0, 54, 0, 29, 11, 0, 0,
	90, 93, 56, 57, 58, 59, 60, 0, 0, 0,
	0, 70, 71, 0, 72, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 50, 51, 0,
	0, 0, 0, 52, 0, 53, 48, 49, 61, 62,
	63, 64, 65, 66, 67, 68, 0, 96, 0, 47,
	0, 0, 0, 0, 22, 73, 74, 0, 0, 0,
	0, 43, 79, 80, 33, 0, 92, 0, 24, 0,
	0, 0, 97, 23, 15, 14, 642, 16, 0, 27,
	0, 28, 0, 0, 17, 0, 0, 0, 18, 19,
	32, 34, 0, 20, 30, 0, 0, 31, 0, 0,
	21, 0, 26, 0, 55, 0, 36, 0, 0, 0,
	0, 0, 0, 95, 0, 88, 84, 85, 86, 81,
	82, 0, 0, 0, 0, 0, 0, 89, 0, 0,
	0, 0, 117, 87, 83, 99, 0, 54, 0, 29,
	11, 0, 0, 90, 93, 56, 57, 58, 59, 60,
	0, 0, 0, 0, 70, 71, 0, 72, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	50, 51, 0, 0, 0, 0, 52, 0, 53, 48,
	49, 61, 62, 63, 64, 65, 66, 67, 68, 0,
	96, 0, 47, 0, 0, 0, 582, 22, 73, 74,
	0, 0, 0, 0, 43, 79, 80, 33, 0, 92,
	0, 24, 0, 0, 0, 97, 23, 15, 14, 0,
	16, 0, 27, 0, 28, 0, 0, 17, 0, 0,
	0, 18, 19, 32, 34, 0, 20, 30, 0, 0,
	31, 0, 0, 21, 0, 26, 0, 55, 0, 36,
	0, 0, 0, 0, 0, 0, 95, 0, 88, 84,
	85, 86, 81, 82, 0, 0, 0, 0, 0, 0,
	89, 0, 0, 0, 0, 117, 87, 83, 99, 0,
	54, 0, 29, 11, 0, 0, 90, 93, 56, 57,
	58, 59, 60, 0, 0, 0, 0, 70, 71, 0,
	72, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 50, 51, 0, 0, 0, 0, 52,
	0, 53, 48, 49, 61, 62, 63, 64, 65, 66,
	67, 68, 0, 96, 0, 47, 0, 0, 0, 0,
	22, 73, 74, 0, 0, 0, 0, 43, 79, 80,
	33, 0, 92, 0, 24, 0, 0, 0, 97, 23,
	15, 14, 0, 16, 0, 27, 0, 28, 0, 0,
	17, 0, 0, 0, 18, 19, 32, 34, 0, 20,
	30, 0, 0, 31, 0, 0, 21, 0, 26, 0,
	55, 0, 36, 0, 0, 0, 0, 0, 0, 95,
	0, 88, 84, 85, 86, 81, 82, 0, 0, 0,
	0, 0, 0, 89, 0, 0, 0, 0, 117, 87,
	83, 99, 0, 54, 0, 29, 11, 491, 0, 90,
	93, 56, 57, 58, 59, 60, 0, 0, 0, 0,
	70, 71, 0, 72, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 50, 51, 0, 0,
	0, 0, 52, 0, 53, 48, 49, 61, 62, 63,
	64, 65, 66, 67, 68, 0, 96, 0, 47, 0,
	0, 0, 0, 22, 73, 74, 0, 0, 0, 0,
	43, 79, 80, 33, 0, 92, 0, 24, 0, 0,
	0, 97, 23, 15, 14, 0, 16, 0, 27, 0,
	28, 0, 0, 17, 0, 0, 0, 18, 19, 32,
	34, 0, 20, 30, 0, 0, 31, 0, 0, 21,
	0, 26, 0, 55, 0, 36, 0, 0, 0, 0,
	0, 0, 95, 0, 88, 84, 85, 86, 81, 82,
	0, 0, 0, 0, 0, 0, 89, 0, 0, 0,
	0, 117, 87, 83, 99, 0, 54, 0, 29, 11,
	268, 0, 90, 93, 56, 57, 58, 59, 60, 0,
	0, 0, 0, 70, 71, 0, 72, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 50,
	51, 0, 0, 0, 0, 52, 0, 53, 48, 49,
	61, 62, 63, 64, 65, 66, 67, 68, 0, 96,
	0, 47, 0, 0, 0, 0, 22, 73, 74, 0,
	0, 0, 0, 43, 79, 80, 33, 0, 92, 0,
	24, 0, 0, 0, 97, 23, 15, 14, 0, 16,
	0, 27, 0, 28, 0, 0, 17, 0, 0, 0,
	18, 19, 32, 34, 0, 20, 30, 0, 0, 31,
	0, 0, 21, 0, 26, 0, 55, 0, 36, 0,
	0, 0, 0, 0, 0, 95, 0, 88, 84, 85,
	86, 81, 82, 0, 0, 0, 0, 0, 0, 89,
	0, 0, 0, 0, 117, 87, 83, 99, 0, 54,
	0, 29, 11, 0, 0, 90, 93, 56, 57, 58,
	59, 60, 0, 0, 0, 0, 70, 71, 0, 72,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 653, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 50, 51, 0, 0, 0, 0, 52, 0,
	53, 48, 49, 61, 62, 63, 64, 65, 66, 67,
	68, 0, 96, 0, 47, 0, 0, 0, 0, 22,
	0, 0, 0, 0, 0, 0, 43, 79, 80, 33,
	0, 92, 0, 24, 0, 0, 0, 97, 23, 15,
	14, 0, 16, 0, 27, 0, 28, 0, 0, 17,
	0, 0, 0, 18, 19, 32, 0, 0, 20, 30,
	0, 0, 31, 0, 0, 21, 0, 26, 0, 55,
	0, 0, 0, 0, 0, 0, 0, 0, 95, 0,
	88, 84, 85, 86, 81, 82, 0, 0, 0, 0,
	0, 0, 89, 0, 0, 0, 0, 117, 87, 83,
	99, 0, 54, 0, 29, 11, 0, 0, 90, 93,
	56, 57, 58, 59, 60, 0, 0, 0, 0, 70,
	71, 0, 72, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 723, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 50, 51, 0, 0, 0,
	0, 52, 0, 53, 48, 49, 61, 62, 63, 64,
	65, 66, 67, 68, 0, 96, 0, 47, 0, 0,
	0, 0, 22, 0, 0, 0, 0, 0, 0, 43,
	79, 80, 33, 0, 92, 0, 24, 0, 0, 0,
	97, 23, 15, 14, 0, 16, 0, 27, 0, 28,
	0, 0, 17, 0, 0, 0, 18, 19, 32, 0,
	0, 20, 30, 0, 0, 31, 0, 0, 21, 0,
	26, 0, 55, 0, 0, 0, 0, 0, 0, 0,
	0, 95, 0, 88, 84, 85, 86, 81, 82, 0,
	0, 0, 0, 0, 0, 89, 0, 0, 0, 0,
	117, 87, 83, 99, 0, 54, 0, 29, 11, 0,
	0, 90, 93, 56, 57, 58, 59, 60, 0, 0,
	0, 0, 70, 71, 0, 72, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	584, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 50, 51,
	0, 0, 0, 0, 52, 0, 53, 48, 49, 61,
	62, 63, 64, 65, 66, 67, 68, 0, 96, 0,
	47, 0, 0, 0, 0, 22, 0, 0, 0, 0,
	0, 0, 43, 79, 80, 33, 0, 92, 0, 24,
	0, 0, 0, 97, 23, 15, 14, 0, 16, 0,
	27, 0, 28, 0, 0, 17, 0, 0, 0, 18,
	19, 32, 0, 0, 20, 30, 0, 0, 31, 0,
	0, 21, 0, 26, 0, 55, 0, 0, 0, 0,
	0, 0, 0, 0, 95, 0, 88, 84, 85, 86,
	81, 82, 0, 0, 0, 0, 0, 0, 89, 0,
	0, 0, 0, 117, 87, 83, 99, 0, 54, 0,
	29, 11, 0, 0, 90, 93, 56, 57, 58, 59,
	60, 0, 0, 0, 0, 70, 71, 0, 72, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 550, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 50, 51, 0, 0, 0, 0, 52, 0, 53,
	48, 49, 61, 62, 63, 64, 65, 66, 67, 68,
	0, 96, 0, 47, 0, 0, 0, 0, 22, 0,
	0, 0, 0, 0, 0, 43, 79, 80, 33, 0,
	92, 0, 24, 0, 0, 0, 97, 23, 15, 14,
	0, 16, 0, 27, 0, 28, 0, 0, 17, 0,
	0, 0, 18, 19, 32, 0, 0, 20, 30, 0,
	0, 31, 0, 0, 21, 0, 26, 0, 55, 0,
	0, 0, 0, 0, 0, 0, 0, 95, 0, 88,
	84, 85, 86, 81, 82, 0, 0, 0, 0, 0,
	0, 89, 0, 0, 0, 0, 117, 87, 83, 99,
	0, 54, 0, 29, 11, 0, 0, 90, 93, 56,
	57, 58, 59, 60, 0, 0, 0, 0, 70, 71,
	0, 72, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 533, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 50, 51, 0, 0, 0, 0,
	52, 0, 53, 48, 49, 61, 62, 63, 64, 65,
	66, 67, 68, 0, 96, 0, 47, 0, 0, 0,
	0, 22, 0, 0, 0, 0, 0, 0, 43, 79,
	80, 33, 0, 92, 0, 24, 0, 0, 0, 97,
	23, 15, 14, 0, 16, 0, 27, 0, 28, 0,
	0, 17, 0, 0, 0, 18, 19, 32, 0, 0,
	20, 30, 0, 0, 31, 0, 0, 21, 0, 26,
	0, 55, 0, 0, 0, 0, 0, 0, 0, 0,
	95, 0, 88, 84, 85, 86, 81, 82, 0, 0,
	0, 0, 0, 0, 89, 0, 0, 0, 0, 117,
	87, 83, 99, 0, 54, 0, 29, 11, 0, 0,
	90, 93, 56, 57, 58, 59, 60, 0, 0, 0,
	0, 70, 71, 0, 72, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 50, 51, 0,
	0, 0, 0, 52, 0, 53, 48, 49, 61, 62,
	63, 64, 65, 66, 67, 68, 0, 96, 0, 47,
	0, 0, 0, 0, 22, 0, 0, 0, 0, 0,
	0, 43, 79, 80, 33, 0, 92, 0, 24, 0,
	0, 0, 97, 23, 15, 14, 0, 16, 0, 27,
	0, 28, 0, 0, 17, 0, 0, 0, 18, 19,
	32, 0, 0, 20, 30, 0, 0, 31, 0, 0,
	21, 0, 26, 0, 55, 0, 0, 0, 0, 0,
	0, 0, 0, 95, 0, 88, 84, 85, 86, 81,
	82, 0, 0, 0, 0, 0, 0, 89, 0, 0,
	0, 0, 117, 87, 83, 99, 0, 54, 0, 29,
	11, 139, 138, 90, 93, 373, 374, 375, 376, 377,
	0, 378, 379, 380, 416, 417, 0, 0, 0, 0,
	161, 0, 162, 135, 136, 140, 142, 141, 154, 155,
	152, 153, 156, 157, 158, 159, 160, 150, 151, 144,
	145, 143, 146, 148, 149, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 381, 147, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 382, 383, 0, 386, 387, 388, 367, 368, 369,
	370, 371, 372, 384, 385, 0, 0, 364, 0, 0,
	0, 0, 0, 0, 0, 0, 389, 390, 391, 392,
	393, 394, 395, 396, 397, 398, 399, 419, 420, 421,
	422, 423, 411, 412, 413, 414, 415, 400, 401, 402,
	403, 404, 405, 406, 407, 408, 409, 410, 0, 431,
	429, 430, 426, 427, 0, 418, 424, 425, 432, 433,
	435, 434, 436, 437, 373, 374, 375, 376, 377, 0,
	378, 379, 380, 416, 417, 428, 439, 438, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 381, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	382, 383, 0, 386, 387, 388, 576, 577, 578, 575,
	574, 573, 384, 385, 0, 0, 753, 0, 0, 0,
	0, 0, 0, 0, 0, 389, 390, 391, 392, 393,
	394, 395, 396, 397, 398, 399, 419, 420, 421, 422,
	423, 411, 412, 413, 414, 415, 400, 401, 402, 403,
	404, 405, 406, 407, 408, 409, 410, 0, 431, 429,
	430, 426, 427, 0, 418, 424, 425, 432, 433, 435,
	434, 436, 437, 0, 0, 0, 0, 0, 56, 57,
	58, 59, 60, 0, 428, 439, 438, 70, 71, 0,
	72, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 247, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 50, 51, 0, 0, 0, 0, 52,
	0, 53, 48, 49, 61, 62, 63, 64, 65, 66,
	67, 68, 0, 96, 0, 47, 0, 137, 139, 138,
	122, 0, 0, 0, 0, 0, 0, 0, 79, 80,
	104, 0, 92, 0, 0, 0, 0, 161, 97, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 56, 57, 58, 59, 60, 0, 0, 0,
	55, 70, 71, 0, 72, 147, 0, 0, 248, 95,
	0, 88, 84, 85, 86, 81, 82, 0, 0, 0,
	0, 0, 0, 89, 0, 520, 0, 0, 117, 87,
	83, 99, 0, 54, 0, 0, 0, 50, 51, 90,
	93, 0, 0, 52, 0, 53, 48, 49, 61, 62,
	63, 64, 65, 66, 67, 68, 0, 96, 0, 47,
	0, 0, 0, 0, 122, 0, 0, 0, 0, 0,
	0, 0, 79, 80, 104, 0, 92, 0, 0, 0,
	0, 0, 97, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	516, 0, 0, 0, 0, 0, 56, 57, 58, 59,
	60, 0, 0, 0, 55, 70, 71, 0, 72, 0,
	0, 0, 521, 95, 0, 88, 84, 85, 86, 81,
	82, 0, 0, 0, 0, 0, 0, 89, 0, 0,
	0, 0, 117, 87, 83, 99, 0, 54, 0, 0,
	0, 50, 51, 90, 93, 0, 0, 52, 0, 53,
	48, 49, 61, 62, 63, 64, 65, 66, 67, 68,
	0, 96, 0, 47, 0, 137, 139, 138, 122, 0,
	0, 0, 0, 0, 0, 0, 79, 80, 104, 450,
	92, 0, 0, 0, 0, 161, 97, 162, 135, 136,
	140, 142, 141, 154, 155, 152, 153, 156, 157, 158,
	159, 160, 150, 151, 144, 145, 143, 146, 148, 149,
	56, 57, 58, 59, 60, 0, 0, 0, 55, 70,
	71, 0, 72, 147, 0, 0, 0, 95, 0, 88,
	84, 85, 86, 81, 82, 0, 0, 0, 0, 0,
	0, 89, 0, 337, 0, 0, 117, 87, 83, 99,
	0, 54, 0, 0, 0, 50, 51, 90, 93, 0,
	0, 52, 0, 53, 48, 49, 61, 62, 63, 64,
	65, 66, 67, 68, 0, 96, 0, 47, 0, 0,
	0, 0, 122, 0, 0, 0, 0, 0, 0, 0,
	79, 80, 104, 0, 92, 0, 0, 0, 0, 0,
	97, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 512, 0,
	0, 0, 0, 0, 56, 57, 58, 59, 60, 0,
	0, 0, 55, 70, 71, 0, 72, 0, 0, 0,
	0, 95, 0, 88, 84, 85, 86, 81, 82, 0,
	0, 315, 0, 0, 0, 89, 0, 0, 0, 0,
	117, 87, 83, 99, 0, 54, 0, 0, 0, 50,
	51, 90, 93, 0, 0, 52, 0, 53, 48, 49,
	61, 62, 63, 64, 65, 66, 67, 68, 0, 96,
	0, 47, 0, 137, 139, 138, 122, 0, 0, 0,
	0, 0, 0, 0, 79, 80, 104, 0, 92, 0,
	0, 0, 0, 161, 97, 162, 135, 136, 140, 142,
	141, 154, 155, 152, 153, 156, 157, 158, 159, 160,
	150, 151, 144, 145, 143, 146, 148, 149, 56, 57,
	58, 59, 60, 0, 0, 0, 55, 70, 71, 0,
	72, 147, 0, 0, 0, 95, 0, 88, 84, 85,
	86, 81, 82, 0, 0, 0, 0, 0, 0, 89,
	0, 0, 0, 0, 117, 87, 83, 99, 0, 54,
	0, 0, 0, 50, 51, 90, 93, 0, 487, 52,
	0, 53, 48, 49, 61, 62, 63, 64, 65, 66,
	67, 68, 0, 96, 0, 47, 0, 0, 0, 0,
	122, 0, 137, 139, 138, 0, 0, 0, 79, 80,
	104, 0, 92, 0, 0, 0, 0, 0, 97, 0,
	0, 0, 161, 687, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 0, 0, 0,
	55, 0, 0, 0, 0, 0, 0, 0, 0, 95,
	147, 88, 84, 85, 86, 81, 82, 0, 0, 0,
	0, 0, 0, 89, 137, 139, 138, 0, 117, 87,
	83, 99, 0, 54, 0, 0, 0, 0, 0, 90,
	93, 0, 0, 0, 161, 0, 162, 135, 136, 140,
	142, 141, 154, 155, 152, 153, 156, 157, 158, 159,
	160, 150, 151, 144, 145, 143, 146, 148, 149, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 147, 0, 137, 139, 138, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 688, 161, 0, 162, 135, 136, 140,
	142, 141, 154, 155, 152, 153, 156, 157, 158, 159,
	160, 150, 151, 144, 145, 143, 146, 148, 149, 137,
	139, 138, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 147, 0, 0, 0, 0, 0, 0, 161,
	0, 162, 135, 136, 140, 142, 141, 154, 155, 152,
	153, 156, 157, 158, 159, 160, 150, 151, 144, 145,
	143, 146, 148, 149, 0, 325, 137, 139, 138, 0,
	0, 0, 0, 0, 0, 0, 0, 147, 0, 0,
	0, 0, 0, 0, 0, 0, 161, 0, 162, 135,
	136, 140, 142, 141, 154, 155, 152, 153, 156, 157,
	158, 159, 160, 150, 151, 144, 145, 143, 146, 148,
	149, 0, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 147, 134, 0, 0, 0, 0,
	0, 0, 161, 0, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 137, 139, 138,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 600,
	147, 0, 0, 0, 0, 0, 0, 161, 0, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 147, 581, 0, 0, 0,
	0, 0, 161, 0, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 137, 139, 138,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	147, 0, 580, 0, 0, 0, 0, 161, 0, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 147, 0, 504, 0, 0,
	0, 0, 161, 0, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 137, 139, 138,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	147, 0, 503, 0, 0, 0, 0, 161, 0, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 147, 0, 502, 0, 0,
	0, 0, 161, 0, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 137, 139, 138,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	147, 0, 500, 0, 0, 0, 0, 161, 0, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 147, 0, 478, 0, 0,
	0, 0, 161, 483, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 137, 139, 138,
	0, 0, 457, 0, 0, 0, 0, 0, 0, 0,
	147, 0, 474, 0, 0, 0, 0, 161, 0, 162,
	135, 136, 140, 142, 141, 154, 155, 152, 153, 156,
	157, 158, 159, 160, 150, 151, 144, 145, 143, 146,
	148, 149, 137, 139, 138, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 147, 0, 358, 0, 0,
	0, 0, 161, 0, 162, 135, 136, 140, 142, 141,
	154, 155, 152, 153, 156, 157, 158, 159, 160, 150,
	151, 144, 145, 143, 146, 148, 149, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	147,
}
var yyPact = [...]int{

	-1000, -1000, 1474, -1000, -1000, -1000, -1000, -1000, 215, 45,
	331, -1000, -1000, -1000, 214, 4408, 202, 197, 5424, 5424,
	5424, 6, 401, 5424, -1000, 5624, 196, 193, 192, -1000,
	16, 5424, 491, 582, 517, 386, 490, 476, 516, 532,
	2466, -1000, -1000, 190, -1000, -1000, 234, 5424, 385, 385,
	5424, 5424, 5424, 5424, 5424, 187, 5424, 5424, 185, 5424,
	5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, -1000,
	5424, 5424, 5424, -1000, -1000, -1000, 298, 296, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 486,
	381, -1000, -1000, 13, -1000, 184, 4854, -1000, 264, 418,
	158, 418, -55, -1000, -1000, 134, 329, 220, 335, 418,
	-1000, -1000, -1000, -1000, 3267, 5424, 355, 225, 5424, 5424,
	132, 6212, -1000, 131, 130, 219, -1000, -1000, 210, -1000,
	612, 208, -1000, 6212, -1000, 5424, 5424, 5424, 5424, 5424,
	5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424,
	5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424,
	5424, 5310, 5424, 385, 5424, 427, -1000, 5564, 128, -1000,
	472, -1000, 467, -1000, -35, -36, 183, 4408, 181, 124,
	572, 5196, 5424, 5424, 5424, 5424, 5424, 5424, 5424, 5424,
	5424, 5424, 5424, 5424, -1000, -1000, 5424, 7, -1000, -1000,
	294, 286, 5424, -1000, -1000, -1000, 475, 475, 475, 475,
	6077, 5424, 6212, 6212, 5424, 6212, 6212, 475, 475, 475,
	475, 475, 475, 475, 475, 1296, 1622, 1296, 725, 725,
	348, -1000, 448, -1000, 373, 5082, 385, 15, 360, 5424,
	-1000, 4854, -82, 654, -1000, -1000, 6167, 385, 180, 463,
	264, 119, 264, -1000, -1000, 1311, -1000, 111, 186, 325,
	418, -1000, 289, 49, 461, 324, -1000, -1000, -1000, -1000,
	-1000, -1000, 6032, 177, 107, 651, 6212, 5987, -1000, -1000,
	-1000, -1000, 6, -1000, 401, 5424, -1000, 5424, 1457, 1783,
	4560, 1296, 1000, 1946, 2268, 2106, 604, 604, 604, 475,
	475, 475, 475, 861, 861, 849, 849, 849, 849, 849,
	2114, 2114, 2114, 2114, 6122, 5424, 1136, 645, -1000, -1000,
	5373, 260, -1000, 608, 3104, -1000, -1000, 176, -38, -1000,
	-1000, 5424, -1000, 5424, -1000, -1000, 1296, 5424, 1296, 1296,
	1296, 1296, 1296, 1296, 1296, 1296, 1296, 1296, 1296, 1296,
	5942, -1000, -1000, 5424, -1000, 6, 6, 5897, -1000, 5852,
	5807, 5424, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, 484, 433, 5145,
	18, -50, -1000, 4917, 155, -1000, 4854, 4968, -1000, 4854,
	-1000, -1000, 1148, -1000, -1000, -1000, 48, 311, -1000, 418,
	280, 394, -1000, 47, 4245, 5424, 5424, 5424, 145, -1000,
	-1000, 6212, -1000, 5424, 1136, 153, 385, 284, 4082, 427,
	5424, -1000, 191, -1000, 828, 347, 5762, 5716, 2941, 2268,
	3919, 354, -1000, -1000, -1000, 1296, -85, -1000, -1000, 370,
	-1000, -1000, -1000, -1000, 5424, -1000, -1000, -1000, -1000, 6212,
	385, 172, 151, -1000, 418, 42, 631, -1000, -1000, 418,
	394, -1000, -1000, -1000, 5669, 80, 6212, -1000, 78, 76,
	1136, 74, -1000, 223, -1000, 385, 165, 4854, -1000, -1000,
	-1000, -1000, 6212, 377, 150, 640, -1000, 546, -1000, -1000,
	222, -1000, -1000, -1000, 333, -1000, -1000, 387, 352, 277,
	674, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	4408, 566, 73, -1000, -1000, -1000, -1000, -1000, 213, -1000,
	4854, -1000, 630, -1000, 418, -51, 394, -1000, 631, 2778,
	72, 5424, 1, -1000, 485, -1000, -1000, 3593, 284, -1000,
	4854, -89, 2615, -1000, 164, -39, 556, 191, 50, -1000,
	-1000, -1000, 168, -1000, 606, 4571, 517, 65, -1000, -1000,
	-1000, -1000, -1000, 3430, -52, 149, -67, 418, 630, -1000,
	-1000, -73, 69, -1000, 144, -1000, 5424, 140, -31, 61,
	457, -1000, -1000, -1000, 143, 139, -1000, 59, 277, -1000,
	-41, 191, -1000, 395, -1000, -1000, 387, 5424, 109, -1000,
	601, 4571, -1000, 277, -1000, 1003, 3430, -1000, -1000, -1000,
	-1000, -75, -1000, -1000, 3756, 5492, -1000, -1000, -1000, -1000,
	-1000, 57, 2452, 3593, -1000, -1000, 468, -1000, 2289, -1000,
	-1000, 598, -1000, 6212, -1000, 4571, 5424, 141, -1000, -1000,
	864, -1000, 55, 52, 334, 367, 282, -1000, 225, -1000,
	-1000, -1000, -1000, -1000, -1000, 3430, -1000, 40, -1000, 137,
	277, -1000, 2126, 5424, -1000, 6212, 191, -1000, -1000, -1000,
	-1000, 277, 4710, 4571, 1963, 3430, -1000, -48, -1000, -1000,
	6212, 136, 623, -1000, -1000, 4571, -1000, 35, -1000, 556,
	-1000, -1000, 1800, -57, -1000, -1000, -1000, -1000, 1637, -1000,
}
var yyPgo = [...]int{

	0, 585, 772, 770, 14, 5, 768, 2, 767, 15,
	34, 70, 27, 766, 1, 764, 46, 38, 762, 3,
	13, 17, 6, 761, 16, 0, 759, 757, 80, 76,
	756, 744, 742, 741, 740, 28, 728, 724, 723, 44,
	646, 722, 47, 720, 56, 718, 45, 717, 39, 18,
	33, 40, 716, 714, 10, 711, 35, 709, 706, 705,
	703, 37, 702, 700, 699, 4, 698, 12, 695, 9,
	694, 7, 692, 691, 8, 690, 687, 685, 683, 682,
	681, 518, 81, 680, 677, 50, 42, 676, 36, 673,
	671, 631, 670, 669, 29, 22, 462, 31, 89, 59,
	665, 664, 23, 11,
}
var yyR1 = [...]int{

	0, 101, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 9, 9,
	10, 10, 10, 11, 11, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 8, 91, 91, 92,
	92, 93, 93, 94, 94, 95, 95, 96, 96, 97,
	97, 98, 98, 99, 99, 14, 14, 13, 13, 13,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 58, 58, 59, 59, 60, 60,
	55, 55, 56, 57, 57, 30, 30, 31, 31, 32,
	32, 33, 33, 34, 34, 35, 35, 36, 36, 38,
	38, 38, 38, 39, 39, 39, 103, 103, 37, 37,
	49, 49, 49, 49, 50, 51, 51, 52, 52, 53,
	53, 53, 53, 53, 53, 54, 54, 41, 41, 42,
	43, 43, 44, 44, 45, 45, 46, 47, 47, 48,
	102, 102, 16, 16, 15, 15, 1, 1, 100, 61,
	61, 62, 62, 62, 62, 71, 71, 72, 72, 72,
	73, 73, 74, 74, 75, 76, 76, 76, 76, 77,
	77, 78, 79, 79, 63, 63, 68, 68, 69, 70,
	70, 64, 64, 65, 65, 65, 65, 65, 65, 66,
	66, 67, 67, 17, 22, 22, 23, 23, 24, 24,
	18, 18, 4, 4, 2, 2, 3, 3, 20, 20,
	21, 21, 21, 19, 19, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 81, 81, 81, 81, 82, 82,
	82, 82, 82, 82, 82, 83, 83, 83, 83, 84,
	84, 84, 85, 85, 86, 87, 87, 87, 88, 88,
	88, 25, 25, 40, 40, 27, 28, 28, 28, 90,
	90, 90, 29, 29, 29, 89, 89,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 2, 3, 2, 0, 1, 1, 1, 1, 4,
	3, 5, 4, 3, 4, 3, 4, 1, 1, 6,
	7, 6, 7, 3, 1, 3, 1, 3, 1, 1,
	2, 1, 3, 1, 2, 2, 0, 1, 1, 1,
	3, 1, 1, 5, 7, 9, 5, 3, 3, 3,
	3, 3, 3, 1, 2, 6, 7, 9, 5, 1,
	6, 3, 3, 2, 0, 9, 1, 3, 0, 4,
	3, 1, 3, 1, 4, 5, 6, 1, 3, 6,
	7, 3, 6, 1, 4, 0, 1, 3, 1, 3,
	4, 4, 5, 0, 5, 4, 1, 1, 1, 4,
	1, 2, 4, 3, 1, 0, 1, 3, 1, 3,
	1, 4, 2, 6, 4, 1, 4, 3, 1, 1,
	3, 1, 1, 3, 3, 1, 1, 1, 3, 1,
	0, 1, 6, 5, 1, 2, 1, 1, 5, 2,
	0, 3, 4, 3, 9, 1, 3, 1, 2, 3,
	1, 2, 2, 2, 3, 3, 3, 4, 3, 1,
	1, 3, 1, 3, 1, 1, 3, 1, 3, 0,
	1, 1, 2, 1, 1, 1, 1, 1, 1, 3,
	1, 1, 3, 10, 1, 0, 1, 3, 4, 6,
	0, 1, 0, 1, 0, 1, 0, 1, 1, 2,
	1, 1, 1, 0, 2, 3, 4, 2, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	2, 2, 2, 2, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 2, 2, 2, 2, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 5, 4, 3, 4, 2,
	2, 4, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 1, 2, 1, 2, 4, 2, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 3, 2,
	3, 3, 1, 1, 2, 2, 1, 2, 1, 4,
	3, 3, 3, 6, 3, 1, 1, 2, 1, 1,
	3, 3, 1, 1, 1, 1, 3, 1, 4, 3,
	1, 1, 1, 0, 1, 1, 1, 1, 3, 1,
	3, 1, 1, 4, 2, 3, 3,
}
var yyChk = [...]int{

	-1000, -101, -11, -8, -12, -17, -16, -100, 127, 154,
	120, 162, -31, -33, 97, 96, 99, 106, 110, 111,
	115, 122, 76, 95, 90, -25, 124, 101, 103, 161,
	116, 119, 112, 86, 113, -15, 128, 129, -30, -32,
	-28, -26, -1, 83, -27, -89, -87, 71, 58, 59,
	49, 50, 55, 57, 159, 126, 4, 5, 6, 7,
	8, 60, 61, 62, 63, 64, 65, 66, 67, -80,
	13, 14, 16, 77, 78, -29, -85, -86, -88, 84,
	85, 141, 142, 156, 138, 139, 140, 155, 137, 149,
	165, -84, 88, 166, -10, 135, 69, 94, -9, 157,
	159, 157, -9, 162, 86, -93, -91, -96, -9, 157,
	113, 114, -99, -98, -14, 159, -12, 154, 159, 159,
	-40, -25, 76, -40, -40, -41, -42, -29, -43, -44,
	88, -45, -46, -25, 161, 33, 34, 10, 12, 11,
	35, 37, 36, 51, 49, 50, 52, 68, 53, 54,
	47, 48, 40, 41, 38, 39, 42, 43, 44, 45,
	46, 30, 32, 159, 159, 159, 162, -25, 86, 31,
	-4, 37, 128, -1, 86, 86, 73, 74, 73, 75,
	74, 17, 18, 19, 20, 29, 21, 22, 23, 24,
	25, 26, 27, 28, 58, 59, 159, 133, -25, -28,
	-85, -86, 159, -88, -10, -28, -25, -25, -25, -25,
	-25, 159, -25, -25, 159, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, 153, 153,
	93, 150, -81, -82, 88, 151, 152, -81, 93, 162,
	-29, 159, -50, -52, -51, -53, -25, 37, 134, 157,
	-9, 160, -9, 161, 162, -11, 161, -92, -96, -9,
	157, 161, 9, 157, 105, -9, -98, -13, 163, -12,
	-17, -16, -25, 97, -35, -36, -25, -25, 161, 161,
	161, 161, 9, 161, 9, 17, 161, 9, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, 31, -25, -47, -48, -28,
	-25, -55, -56, 86, -14, 161, 161, 86, 86, 162,
	162, 159, -12, 159, 161, 31, -25, 37, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -90, 86, 162, -29, 153, 153, -25, 160, -25,
	-25, 15, -7, -29, 86, -6, -5, 76, 77, 78,
	79, 80, 81, 4, 5, 6, 7, 8, 10, 11,
	12, 56, 70, 71, 82, 83, 73, 74, 75, 95,
	96, 97, 98, 99, 100, 101, 102, 103, 104, 105,
	116, 117, 118, 119, 120, 121, 122, 123, 124, 125,
	126, 111, 112, 113, 114, 115, 13, 14, 134, 106,
	107, 108, 109, 110, 135, 136, 131, 132, 154, 129,
	130, 128, 137, 138, 140, 139, 141, 142, 156, 155,
	-7, -29, 150, -82, 150, -82, 93, 69, 133, -25,
	87, -28, 165, -25, -50, 164, 9, 15, -28, 159,
	86, 161, -11, 163, 161, 161, 157, -9, -99, 157,
	-9, 162, 86, 157, 160, 159, 161, 9, 160, -42,
	-44, -25, -46, 31, -25, -102, 9, 105, 160, 9,
	17, 163, 159, 162, -61, -61, -25, -25, -14, -25,
	160, -25, 160, 160, 160, -25, -83, 86, 89, 50,
	88, 86, 163, 163, 69, 163, 163, 160, -51, -25,
	37, 134, -50, 163, 162, 157, -94, -97, -98, -91,
	162, -34, -12, 31, -25, -35, -25, -38, 162, 31,
	-25, 160, -48, -49, -28, 37, 134, 69, -57, -12,
	31, -56, -25, -58, -22, -23, -24, -18, -20, -21,
	30, -10, 135, 136, -61, 163, -62, -63, -70, 120,
	-64, 123, -65, 81, 80, 79, 76, 77, 78, 163,
	160, 160, 75, -12, 31, 163, 164, 89, -25, -28,
	159, 160, -95, -98, 162, -102, 9, -98, -94, -14,
	160, 161, -39, 161, -39, 161, 161, 160, 15, -28,
	159, -50, -14, -60, 117, 118, 160, 9, -2, 37,
	-21, 163, -66, -67, 88, 114, 113, -71, -10, -65,
	-12, 31, 161, -14, 164, -50, -102, 9, -95, 163,
	-97, -102, 98, 161, -35, 163, 108, 109, -39, 107,
	-39, -54, -12, 31, -49, -50, 164, 104, 159, 162,
	-19, 31, -24, -3, 158, 161, 9, 17, -68, -69,
	-7, -4, -72, 9, 161, 162, -14, 163, 160, 163,
	-98, -102, 163, 161, 160, -25, -103, 31, 161, 163,
	161, 107, -14, 160, 160, 161, -59, -10, -14, 162,
	-20, 88, -67, -25, 161, 9, 17, -7, -10, 163,
	-73, -74, -75, -76, -78, -77, -10, -7, 154, 86,
	163, -37, -12, 31, -103, -14, 161, 102, -54, 88,
	35, 163, -14, 17, -69, -25, 159, 163, -74, 161,
	161, 121, 105, 153, -14, -14, 161, 160, -10, 163,
	-25, -22, -71, 86, -5, -65, -7, 100, 162, 160,
	-7, 161, -14, -19, 163, -79, 161, 162, -14, 163,
}
var yyDef = [...]int{

	84, -2, 1, 83, 85, 86, 87, 88, 0, 0,
	0, 116, 121, 122, 0, 0, 0, 0, 403, 403,
	403, 0, 392, 0, 133, 0, 0, 0, 0, 139,
	0, 0, 0, 78, 272, 0, 0, 0, 157, 0,
	-2, 402, 214, 0, 406, 407, 394, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 352,
	0, 354, 0, 216, 217, 405, 0, 0, -2, 358,
	359, 360, 361, 362, 363, 364, 365, 366, 367, 0,
	0, 373, 412, 0, -2, 0, 185, 400, 80, 0,
	0, 0, 0, 84, 78, 0, 0, 0, 111, 0,
	97, 98, 108, 113, 0, 0, 0, 0, 165, 0,
	0, 404, 392, 0, 0, 0, 198, 199, 0, 201,
	202, 0, 205, 206, 134, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 116, 0, 0, 143,
	0, 273, 0, 215, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 300, 302, 0, 0, 287, -2,
	0, 0, 0, 397, 393, -2, 321, 322, 323, 324,
	0, 0, 339, 340, 0, 342, 343, 344, 345, 346,
	347, 348, 349, 350, 351, 353, 355, 357, 0, 0,
	0, 369, 0, 376, 378, 0, 0, 0, 0, 0,
	414, 185, 0, 184, 188, 186, 190, 0, 0, 0,
	81, 0, 82, 90, 84, 0, 93, 0, 0, 111,
	0, 95, 0, 0, 0, 111, 114, 115, 120, 117,
	118, 119, 0, 0, 0, 166, 168, 0, 127, 128,
	129, 130, 0, 131, 0, 0, 132, 0, 304, 305,
	306, 307, 308, 309, 310, 311, 312, 313, 314, 315,
	316, 317, 318, 319, 320, -2, -2, -2, -2, -2,
	-2, -2, -2, -2, 0, 0, 337, 210, 207, -2,
	0, 0, 151, 0, 0, 141, 142, 0, 0, 220,
	220, 0, 158, 0, 161, 116, 285, 0, 288, 289,
	290, 291, 292, 293, 294, 295, 296, 297, 298, 299,
	0, 408, 409, 0, 411, 0, 0, 0, -2, 0,
	0, 0, 390, 415, 76, 77, 69, 70, 71, 72,
	73, 74, 75, 2, 3, 4, 5, 6, 7, 8,
	9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
	19, 20, 21, 22, 23, 24, 25, 26, 27, 28,
	29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
	39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
	49, 50, 51, 52, 53, 54, 55, 56, 57, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
	391, 416, 368, 377, 371, 374, 375, 0, 0, 0,
	0, 395, 370, 0, 0, 399, 185, 0, -2, 185,
	79, 89, 0, 92, 94, 96, 0, 111, 107, 0,
	111, 0, 112, 0, 0, 0, 165, 0, 0, 197,
	200, 203, 204, 0, 336, 0, 211, 0, 0, 0,
	0, 144, -2, 220, 249, 249, 0, 0, 0, 286,
	0, 0, 396, 338, 341, 356, 0, 385, 386, 0,
	388, 380, 381, 382, 0, 384, 413, 398, 187, 189,
	0, 0, 0, 91, 0, 0, 210, 104, 109, 0,
	0, 123, 163, 116, 0, 0, 167, 126, 173, 173,
	335, 0, 208, 0, -2, 0, 0, 185, 138, 153,
	116, 150, 152, 148, 0, 264, 266, 274, 271, 278,
	0, 280, 281, 282, 249, 213, 219, 0, 0, 0,
	-2, 245, 251, 253, 254, 255, 256, 257, 258, 218,
	0, 0, 0, 155, 116, 410, 379, 387, 0, -2,
	185, 194, 210, 106, 0, 0, 211, 110, 210, 0,
	0, 165, 0, 173, 0, 173, 135, 0, 0, -2,
	185, 0, 0, 140, 0, 0, 283, 270, 276, 275,
	279, 212, 0, 260, 261, 0, 272, 0, 225, 252,
	156, 116, 162, 159, 0, 0, 0, 211, 210, 101,
	103, 0, 0, 124, 0, 169, 0, 0, 0, 0,
	0, 136, 195, 116, 0, 0, -2, 0, 0, 116,
	0, 0, 267, 0, 277, 221, 0, 0, 0, 247,
	0, 0, 223, 0, 227, 0, 160, 383, 193, 99,
	105, 0, 102, 164, 0, 0, 116, 176, 177, 170,
	171, 0, 0, 0, 182, 154, 0, 146, 0, 116,
	284, 268, 259, 262, 222, 0, 0, 0, 226, 228,
	0, 230, 0, 0, 240, 0, 0, 239, 57, -2,
	100, 125, 178, 116, 116, 175, 172, 0, 137, 0,
	0, 149, 0, 0, 246, 248, -2, 229, 231, 232,
	233, 0, 0, 0, 0, 174, 196, 0, 147, 263,
	269, 0, 234, 235, 236, 238, 241, 0, 116, 283,
	237, 179, 0, 0, 145, 224, 242, 116, 0, 243,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 165, 3, 166, 54, 37, 3,
	159, 160, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 161,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 162, 35, 163, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:299
		{
			fmt.Println(yyDollar[1].node)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:303
		{
			yyVAL.value = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:304
		{
			yyVAL.value = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.value = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.value = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.value = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:308
		{
			yyVAL.value = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:309
		{
			yyVAL.value = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:313
		{
			yyVAL.value = yyDollar[1].value
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:314
		{
			yyVAL.value = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:318
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].token)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:319
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].value)
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:324
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:328
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 81:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:329
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 82:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:330
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:334
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 84:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:335
		{
			yyVAL.node = Node("Statements")
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:339
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:340
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:341
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:344
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 90:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:346
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 91:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:348
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 92:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:349
		{
			yyVAL.node = Node("Namespace").append(yyDollar[3].node)
		}
	case 93:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:350
		{
			yyVAL.node = yyDollar[2].node
		}
	case 94:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:351
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 95:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = yyDollar[2].node
		}
	case 96:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:353
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:357
		{
			yyVAL.node = Node("FuncUseType")
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:358
		{
			yyVAL.node = Node("ConstUseType")
		}
	case 99:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:363
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 100:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 101:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 102:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:372
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:377
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 104:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:378
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:382
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 106:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:383
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:386
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:387
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:390
		{
			yyVAL.node = yyDollar[1].node
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:391
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:394
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node)
		}
	case 112:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:395
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node).append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:398
		{
			yyVAL.node = yyDollar[1].node
		}
	case 114:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:399
		{
			yyVAL.node = yyDollar[2].node
		}
	case 115:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:403
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 116:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:404
		{
			yyVAL.node = Node("stmt")
		}
	case 117:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:408
		{
			yyVAL.node = yyDollar[1].node
		}
	case 118:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:409
		{
			yyVAL.node = yyDollar[1].node
		}
	case 119:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:410
		{
			yyVAL.node = yyDollar[1].node
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = yyDollar[2].node
		}
	case 121:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:414
		{
			yyVAL.node = yyDollar[1].node
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:415
		{
			yyVAL.node = yyDollar[1].node
		}
	case 123:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:417
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 124:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:423
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 125:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:429
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 126:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 127:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:437
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 128:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:438
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 129:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:439
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 130:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:440
		{
			yyVAL.node = yyDollar[2].node
		}
	case 131:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:441
		{
			yyVAL.node = yyDollar[2].node
		}
	case 132:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:442
		{
			yyVAL.node = yyDollar[2].node
		}
	case 133:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:443
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 134:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:444
		{
			yyVAL.node = yyDollar[1].node
		}
	case 135:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:446
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 136:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:448
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 137:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:455
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 138:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:462
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:463
		{
			yyVAL.node = Node("")
		}
	case 140:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:465
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 141:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:471
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 142:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:472
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 143:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:473
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 144:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = Node("CatchList")
		}
	case 145:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:478
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 146:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:481
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 147:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:482
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 148:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:486
		{
			yyVAL.node = Node("")
		}
	case 149:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:487
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 150:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:491
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 151:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:492
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:496
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 153:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:500
		{
			yyVAL.node = yyDollar[1].node
		}
	case 154:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:501
		{
			yyVAL.node = yyDollar[2].node
		}
	case 155:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:506
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 156:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:510
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:516
		{
			yyVAL.node = yyDollar[1].node
		}
	case 158:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:518
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 159:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:525
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 160:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:529
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 161:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:535
		{
			yyVAL.node = yyDollar[1].node
		}
	case 162:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:537
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 163:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:543
		{
			yyVAL.node = yyDollar[1].node
		}
	case 164:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:544
		{
			yyVAL.node = yyDollar[2].node
		}
	case 165:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:548
		{
			yyVAL.node = Node("")
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:549
		{
			yyVAL.node = yyDollar[1].node
		}
	case 167:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:552
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:553
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 169:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:557
		{
			yyVAL.node = yyDollar[2].node
		}
	case 170:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:558
		{
			yyVAL.node = yyDollar[3].node
		}
	case 171:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:559
		{
			yyVAL.node = yyDollar[2].node
		}
	case 172:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:560
		{
			yyVAL.node = yyDollar[3].node
		}
	case 173:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:564
		{
			yyVAL.node = Node("CaseList")
		}
	case 174:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:566
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 175:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:570
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:581
		{
			yyVAL.node = yyDollar[1].node
		}
	case 179:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:582
		{
			yyVAL.node = yyDollar[2].node
		}
	case 180:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:586
		{
			yyVAL.node = yyDollar[1].node
		}
	case 181:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:587
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 182:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:588
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 183:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:589
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 184:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:593
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 185:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:597
		{
			yyVAL.node = Node("")
		}
	case 186:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:598
		{
			yyVAL.node = yyDollar[1].node
		}
	case 187:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:603
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 188:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:604
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 189:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:608
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:609
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 191:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:610
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 192:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 193:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:613
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 194:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:619
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 195:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:626
		{
			yyVAL.node = yyDollar[1].node
		}
	case 196:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:627
		{
			yyVAL.node = yyDollar[2].node
		}
	case 197:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:636
		{
			yyVAL.node = yyDollar[1].node
		}
	case 200:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:641
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 202:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:645
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 203:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:646
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 204:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:650
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:651
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:655
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 207:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:659
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 208:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:660
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:664
		{
			yyVAL.node = yyDollar[1].node
		}
	case 212:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:674
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token).append(yyDollar[5].node)
		}
	case 213:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:675
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:679
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 215:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:680
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 216:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:684
		{
			yyVAL.value = "abstract"
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:685
		{
			yyVAL.value = "final"
		}
	case 218:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:689
		{
			yyVAL.node = Node("Trait").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 219:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:693
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 220:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:694
		{
			yyVAL.node = Node("Stmt")
		}
	case 221:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:698
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 222:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:699
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 223:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:700
		{
			yyVAL.node = Node("Use").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 224:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = Node("Function").
				append(yyDollar[1].node).
				append(Node("name").append(yyDollar[4].node)).
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[6].node).
				append(yyDollar[8].node).
				append(yyDollar[9].node)
		}
	case 225:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:715
		{
			yyVAL.node = Node("NameList").append(yyDollar[1].node)
		}
	case 226:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:720
		{
			yyVAL.node = Node("")
		}
	case 228:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:721
		{
			yyVAL.node = Node("")
		}
	case 229:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:722
		{
			yyVAL.node = yyDollar[2].node
		}
	case 230:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:726
		{
			yyVAL.node = Node("TraitAdaptionList").append(yyDollar[1].node)
		}
	case 231:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:727
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 232:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:731
		{
			yyVAL.node = yyDollar[1].node
		}
	case 233:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:732
		{
			yyVAL.node = yyDollar[1].node
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = Node("TraitPrecedence").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 235:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 236:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:743
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").append(Node("reservedNonModifiers")))
		}
	case 237:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:745
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 239:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:749
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node)
		}
	case 240:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:750
		{
			yyVAL.node = yyDollar[1].node
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:754
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 242:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:758
		{
			yyVAL.node = Node("")
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:759
		{
			yyVAL.node = yyDollar[2].node
		}
	case 244:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:763
		{
			yyVAL.node = yyDollar[1].node
		}
	case 245:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:764
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:768
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:769
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:773
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 249:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:777
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 250:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:778
		{
			yyVAL.node = yyDollar[1].node
		}
	case 251:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:781
		{
			yyVAL.node = yyDollar[1].node
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:782
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 253:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:785
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 254:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:786
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 255:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:787
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 256:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:788
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 257:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:789
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 258:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:790
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:794
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 260:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:795
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 261:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:798
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:799
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 263:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:804
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 264:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:815
		{
			yyVAL.node = yyDollar[1].node
		}
	case 265:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:816
		{
			yyVAL.node = Node("Parameter list")
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:819
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 267:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:820
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 268:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:824
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 269:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:832
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 270:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:843
		{
			yyVAL.node = Node("No type")
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:844
		{
			yyVAL.node = yyDollar[1].node
		}
	case 272:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:848
		{
			yyVAL.value = "false"
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:849
		{
			yyVAL.value = "true"
		}
	case 274:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:853
		{
			yyVAL.value = "false"
		}
	case 275:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:854
		{
			yyVAL.value = "true"
		}
	case 276:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:858
		{
			yyVAL.value = "false"
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:859
		{
			yyVAL.value = "true"
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:863
		{
			yyVAL.node = yyDollar[1].node
		}
	case 279:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:864
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 280:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:868
		{
			yyVAL.node = yyDollar[1].node
		}
	case 281:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:869
		{
			yyVAL.node = Node("array type")
		}
	case 282:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:870
		{
			yyVAL.node = Node("callable type")
		}
	case 283:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:874
		{
			yyVAL.node = Node("void")
		}
	case 284:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:875
		{
			yyVAL.node = yyDollar[2].node
		}
	case 285:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:879
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 286:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:880
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 287:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:881
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 288:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:882
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 289:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:883
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 290:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:884
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 291:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:885
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 292:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:886
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 293:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:887
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 294:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:888
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 295:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:889
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 296:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:890
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 297:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:891
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 298:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:892
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 299:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:893
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 300:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:894
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 301:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:895
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 302:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:896
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 303:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:897
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:898
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:899
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:900
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:901
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:902
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:903
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 310:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:904
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 311:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:905
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 312:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:906
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 313:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:907
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 314:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:908
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:909
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:910
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:911
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:912
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:913
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 320:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:914
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 321:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:915
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 322:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:916
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 323:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:917
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 324:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:918
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:919
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:920
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:921
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:922
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:923
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:924
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:925
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:926
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 333:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:927
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 334:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:928
		{
			yyVAL.node = yyDollar[2].node
		}
	case 335:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:929
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 336:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:930
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:931
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 338:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:932
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 339:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:933
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 340:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:934
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 341:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:935
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 342:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:936
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 343:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:937
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 344:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:938
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 345:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:939
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 346:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:940
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 347:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:941
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 348:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:942
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 349:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:943
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 350:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:944
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 351:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:945
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:946
		{
			yyVAL.node = yyDollar[1].node
		}
	case 353:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:947
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 354:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:948
		{
			yyVAL.node = Node("Yield")
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:949
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 356:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:950
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 357:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:951
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 358:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:955
		{
			yyVAL.node = Node("Scalar").append(Node("Lnumber").attribute("value", yyDollar[1].token))
		}
	case 359:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:956
		{
			yyVAL.node = Node("Scalar").append(Node("Dnumber").attribute("value", yyDollar[1].token))
		}
	case 360:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:957
		{
			yyVAL.node = Node("Scalar").append(Node("__LINE__"))
		}
	case 361:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:958
		{
			yyVAL.node = Node("Scalar").append(Node("__FILE__"))
		}
	case 362:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:959
		{
			yyVAL.node = Node("Scalar").append(Node("__DIR__"))
		}
	case 363:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:960
		{
			yyVAL.node = Node("Scalar").append(Node("__TRAIT__"))
		}
	case 364:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:961
		{
			yyVAL.node = Node("Scalar").append(Node("__METHOD__"))
		}
	case 365:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:962
		{
			yyVAL.node = Node("Scalar").append(Node("__FUNCTION__"))
		}
	case 366:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:963
		{
			yyVAL.node = Node("Scalar").append(Node("__NAMESPACE__"))
		}
	case 367:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:964
		{
			yyVAL.node = Node("Scalar").append(Node("__CLASS__"))
		}
	case 368:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:966
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc").attribute("value", yyDollar[2].token))
		}
	case 369:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:968
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc"))
		}
	case 370:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:969
		{
			yyVAL.node = yyDollar[2].node
		}
	case 371:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:970
		{
			yyVAL.node = yyDollar[2].node
		}
	case 372:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:971
		{
			yyVAL.node = yyDollar[1].node
		}
	case 373:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:972
		{
			yyVAL.node = yyDollar[1].node
		}
	case 374:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:976
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 375:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:977
		{
			yyVAL.node = yyDollar[1].node.append(Node("String").attribute("value", yyDollar[2].token))
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:978
		{
			yyVAL.node = Node("EncapsList").append(yyDollar[1].node)
		}
	case 377:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:979
		{
			yyVAL.node = Node("EncapsList").append(Node("String").attribute("value", yyDollar[1].token)).append(yyDollar[2].node)
		}
	case 378:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:982
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 379:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:983
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("offset").append(yyDollar[3].node))
		}
	case 380:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:984
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("property").attribute("value", yyDollar[3].token))
		}
	case 381:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:985
		{
			yyVAL.node = Node("Variable").append(Node("expr").append(yyDollar[2].node))
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:986
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token)
		}
	case 383:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:988
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).append(Node("offset").append(yyDollar[4].node))
		}
	case 384:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:989
		{
			yyVAL.node = yyDollar[2].node
		}
	case 385:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:992
		{
			yyVAL.node = Node("OffsetString").attribute("value", yyDollar[1].token)
		}
	case 386:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:993
		{
			yyVAL.node = Node("OffsetNumString").attribute("value", yyDollar[1].token)
		}
	case 387:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:994
		{
			yyVAL.node = Node("OffsetNegateNumString").attribute("value", yyDollar[2].token)
		}
	case 388:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:995
		{
			yyVAL.node = Node("OffsetVariable").attribute("value", yyDollar[1].token)
		}
	case 389:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:999
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node)
		}
	case 390:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1000
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 391:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1002
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 392:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1006
		{
			yyVAL.node = Node("Static")
		}
	case 393:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1007
		{
			yyVAL.node = yyDollar[1].node
		}
	case 394:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1011
		{
			yyVAL.node = yyDollar[1].node
		}
	case 395:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1015
		{
			yyVAL.node = yyDollar[1].node
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1016
		{
			yyVAL.node = yyDollar[2].node
		}
	case 397:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1017
		{
			yyVAL.node = yyDollar[1].node
		}
	case 398:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1021
		{
			yyVAL.node = yyDollar[3].node
		}
	case 399:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1022
		{
			yyVAL.node = yyDollar[2].node
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1023
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 401:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1027
		{
			yyVAL.node = yyDollar[1].node
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1028
		{
			yyVAL.node = yyDollar[1].node
		}
	case 403:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1032
		{
			yyVAL.node = Node("")
		}
	case 404:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1033
		{
			yyVAL.node = yyDollar[1].node
		}
	case 405:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1037
		{
			yyVAL.node = yyDollar[1].node
		}
	case 406:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1041
		{
			yyVAL.node = yyDollar[1].node
		}
	case 407:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1042
		{
			yyVAL.node = yyDollar[1].node
		}
	case 408:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1043
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 409:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1047
		{
			yyVAL.node = Node("PropertyName").attribute("value", yyDollar[1].token)
		}
	case 410:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1048
		{
			yyVAL.node = yyDollar[2].node
		}
	case 411:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1049
		{
			yyVAL.node = yyDollar[1].node
		}
	case 412:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1053
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 413:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1054
		{
			yyVAL.node = Node("Variable").append(yyDollar[3].node)
		}
	case 414:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1055
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	case 415:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1060
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 416:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1062
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	}
	goto yystack /* stack new state and value */
}
